==> moodle-1.5-mysql.tgz: moodle/lang/fi/editor.php <==
<?PHP // $Id$ 
      // editor.php - created with Moodle 1.5 + (2005060201)


$string['about'] = 'Tietoja editorista';
$string['absbottom'] = 'Absbottom';
$string['address'] = 'Osoite';
$string['alertnoselectedtext'] = 'Valitse teksti ensin';
$string['alignment'] = 'Tasaus';
$string['alternatetext'] = 'Oletusteksti';
$string['anchorhelp'] = 'Tm luo vain ankkurin. Sinun pit luoda akkuriin viittaava linkki itse.';
$string['anchorname'] = 'Ankkurin nimi';
$string['anchors'] = 'Ankkurit';
$string['baseline'] = 'Baseline';
$string['bold'] = 'Lihavoitu';
$string['borderthickness'] = 'Reunan paksuus';
$string['bottom'] = 'Pohja';
$string['browse'] = 'Selaa';
$string['cancel'] = 'Peruuta';
$string['cellpadding'] = 'Solun tytt';
$string['cellspacing'] = 'Solujen vli';
$string['choosechar'] = 'Valitse merkki';
$string['chooseicon'] = 'Valitse liitettv hymi';
$string['close'] = 'Sulje';
$string['closeafterreplace'] = 'Sulje korvauksen jlkeen';
$string['cols'] = 'Solut';
$string['copy'] = 'Kopioi';
$string['createanchor'] = 'Luo ankkuri';
$string['createfolder'] = 'Luo kansio';
$string['createlink'] = 'Lis linkki';
$string['cut'] = 'Leikkaa';
$string['cutpastemozilla'] = 'Pahus, et voi kytt normaaleja nppinyhdistelmi liittksesi teksiti tnne. Tmn est Mozilla ja Firefox selainten tietoturva ominaisuudet.<br />
Voit kokeilla jotain seuraavista vaihtoehdoista:<br />
(1) kayt SHIFT-Insert nppimi<br />
(2) kyt valikkokomentoa Muokkaa -> Liit <br />
(3) muuta selaimen asetuksia prefs.js tiedostoa muokkaamaalla<br />
Klikkaa \"OK\" saadaksesi lis ohjeita tai \"Peruuta\" palataksesi tekstisi pariin >br />
';
$string['delete'] = 'Poista';
$string['filebrowser'] = 'Tiedostoselain';
$string['findwhat'] = 'Etsi';
$string['fontname'] = 'Kirjasin';
$string['fontsize'] = 'Koko';
$string['forecolor'] = 'Tekstin vri';
$string['formatblock'] = 'Muoto';
$string['fullscreen'] = 'Tydenruudun editori';
$string['heading'] = 'Otsikko';
$string['height'] = 'Korkeus';
$string['hilitecolor'] = 'Taustan vri';
$string['horizontal'] = 'Vaaka';
$string['horizontalrule'] = 'Vaakaviiva';
$string['htmlmode'] = 'Nyt HTML-koodi';
$string['imageurl'] = 'Kuvan URL';
$string['indent'] = 'Lis sisennyst';
$string['insertchar'] = 'Lis merkki';
$string['insertimage'] = 'Lis kuva';
$string['insertlink'] = 'Lis linkki';
$string['insertsmile'] = 'Lis hymi';
$string['inserttable'] = 'Lis taulukko';
$string['italic'] = 'Kursivoitu';
$string['itemsreplaced'] = 'kohdetta korvattu!';
$string['justifycenter'] = 'Keskit';
$string['justifyfull'] = 'Tasaa molemmat reunat';
$string['justifyleft'] = 'Tasaa vasen reuna';
$string['justifyright'] = 'Tasaa oikea reuna';
$string['layout'] = 'Ulkoasu';
$string['left'] = 'Vasen';
$string['lefttoright'] = 'Suunta vesemmalta oikealle';
$string['linkproperties'] = 'Linkin ominaisuudet';
$string['linktarget'] = 'Linkin kohde';
$string['linktargetblank'] = 'Uuteen ikkunaan';
$string['linktargetnone'] = 'Ei kohdetta';
$string['linktargetother'] = 'Muuhun kehykseen (ei toiminnassa)';
$string['linktargetself'] = 'Samaan kehykseen';
$string['linktargettop'] = 'Samaan ikkunaan';
$string['linktitle'] = 'Otsikko';
$string['linkurl'] = 'URL';
$string['matchcase'] = 'Huomioi kirjainkoko';
$string['middle'] = 'Keskit';
$string['minimize'] = 'Pienenn editori';
$string['move'] = 'Siirr';
$string['nolink'] = 'Est automaattinen linkitys';
$string['normal'] = 'Normaali';
$string['notimage'] = 'Valittu tiedosto ei ollut kuva. Valitse kuvatiedosto!';
$string['notset'] = 'Ei valittua';
$string['ok'] = 'OK';
$string['options'] = 'Vaihtoehdot';
$string['orderedlist'] = 'Numerointi';
$string['outdent'] = 'Vhenn sisennyst';
$string['paste'] = 'Liit';
$string['path'] = 'Polku';
$string['percent'] = 'Prosenttia';
$string['pixels'] = 'Pikseli';
$string['popupeditor'] = 'Suurenna editori';
$string['preformatted'] = 'Esimuotoiltu';
$string['preview'] = 'Esikatsele';
$string['properties'] = 'Ominaisuudet';
$string['redo'] = 'Palauta viimeinen toiminto';
$string['removelink'] = 'Poista linkki';
$string['rename'] = 'Nime uudelleen';
$string['replaceall'] = 'Korvaa kaikki';
$string['replacewith'] = 'Korvaa';
$string['right'] = 'Oikea';
$string['righttoleft'] = 'Suunta oikealta vasemmalle';
$string['rows'] = 'Rivit';
$string['searchandreplace'] = 'Etsi ja korvaa';
$string['searchnotfound'] = 'Merkkijonoa ei lytynyt!';
$string['selectcolor'] = 'Valitse vri';
$string['selection'] = 'Valinta';
$string['showhelp'] = 'Ohje';
$string['size'] = 'Koko';
$string['spacing'] = 'Vlistys';
$string['strikethrough'] = 'Yliviivattu';
$string['subscript'] = 'Alaindeksi';
$string['superscript'] = 'Yldeksi';
$string['textindicator'] = 'Nykyinen tyyli';
$string['textmode'] = 'Olet tekstitilassa.  Kyt [<>] painiketta palataksesi takaisin WYSIWYG -tilaan.';
$string['texttop'] = 'Texttop';
$string['top'] = 'Yls';
$string['type'] = 'Tyyppi';
$string['underline'] = 'Alleviivattu';
$string['undo'] = 'Peruuta viimeisin toiminto';
$string['unorderedlist'] = 'Luettelomerkit';
$string['upload'] = 'Lataa';
$string['vertical'] = 'Pysty';
$string['width'] = 'Leveys';
$string['wordclean'] = 'Puhdista Word HTML';
$string['zip'] = 'Zip';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/fi/editor.php <==
<?PHP // $Id$ 
      // editor.php - created with Moodle 1.5.2 + (2005060222)


$string['about'] = 'Tietoja editorista';
$string['absbottom'] = 'Absbottom';
$string['address'] = 'Osoite';
$string['alertnoselectedtext'] = 'Sinun on valittava teksti ensin!';
$string['alignment'] = 'Tasaus';
$string['alternatetext'] = 'Oletusteksti';
$string['anchorhelp'] = 'Tm luo vain ankkurin. Sinun pit luoda akkuriin viittaava linkki itse.';
$string['anchorname'] = 'Ankkurin nimi';
$string['anchors'] = 'Ankkurit';
$string['baseline'] = 'Baseline';
$string['bold'] = 'Lihavoitu';
$string['borderthickness'] = 'Reunan paksuus';
$string['bottom'] = 'Pohja';
$string['browse'] = 'Selaa';
$string['cancel'] = 'Peruuta';
$string['cellpadding'] = 'Solun tytt';
$string['cellspacing'] = 'Solujen vli';
$string['choosechar'] = 'Valitse merkki';
$string['chooseicon'] = 'Valitse liitettv hymi';
$string['close'] = 'Sulje';
$string['closeafterreplace'] = 'Sulje korvaamisen jlkeen';
$string['cols'] = 'Solut';
$string['copy'] = 'Kopioi';
$string['createanchor'] = 'Luo ankkuri';
$string['createfolder'] = 'Luo kansio';
$string['createlink'] = 'Lis linkki';
$string['cut'] = 'Leikkaa';
$string['cutpastemozilla'] = 'Valitettavasti et voi kytt tavallisia pikanppinyhdistelmi (tai edes Liit-painiketta) liittksesi teksti editoriin. Tm johtuu joihinkin Mozilla- ja Firefox-selaimiin tehdyist turvallisuusominaisuudesta.
<br /><br />
Tm ominaisuus voidaan haluttaessa kiert (muuta muista, kyse on turvallisuudesta!):<br />
(1) Kokeile yhdistelm Shift+v Ctrl+v:n sijaan<br />
(2) Kyt selaimesi Muokkaa -> Liit-valikkoa <br />
(3) Vaihda selaimesi asetuksia muokkaamalla user.js -tiedostoa.<br />
Napsauta alla olevaa OK-painiketta saadaksesi lis apua tai Cancel-painiketta palataksesi editoriin.';
$string['delete'] = 'Poista';
$string['filebrowser'] = 'Tiedostoselain';
$string['findwhat'] = 'Etsi';
$string['fontname'] = 'Fontin nimi';
$string['fontsize'] = 'Fontin koko';
$string['forecolor'] = 'Tekstin vri';
$string['formatblock'] = 'Muoto';
$string['fullscreen'] = 'Tydenruudun editori';
$string['heading'] = 'Otsikko';
$string['height'] = 'Korkeus';
$string['hilitecolor'] = 'Taustan vri';
$string['horizontal'] = 'Vaaka';
$string['horizontalrule'] = 'Vaakaviiva';
$string['htmlmode'] = 'Nyt HTML-koodi';
$string['imageurl'] = 'Kuvan URL';
$string['indent'] = 'Lis sisennyst';
$string['insertchar'] = 'Lis merkki';
$string['insertimage'] = 'Lis kuva';
$string['insertlink'] = 'Lis linkki';
$string['insertsmile'] = 'Lis hymi';
$string['inserttable'] = 'Lis taulukko';
$string['italic'] = 'Kursivoitu';
$string['itemsreplaced'] = 'Kohteet korvattu!';
$string['justifycenter'] = 'Keskit';
$string['justifyfull'] = 'Tasaa molemmat reunat';
$string['justifyleft'] = 'Tasaa vasen reuna';
$string['justifyright'] = 'Tasaa oikea reuna';
$string['layout'] = 'Ulkoasu';
$string['left'] = 'Vasen';
$string['lefttoright'] = 'Suunta vesemmalta oikealle';
$string['linkproperties'] = 'Linkin ominaisuudet';
$string['linktarget'] = 'Linkin kohde';
$string['linktargetblank'] = 'Uuteen ikkunaan';
$string['linktargetnone'] = 'Ei kohdetta';
$string['linktargetother'] = 'Muuhun kehykseen (ei toiminnassa)';
$string['linktargetself'] = 'Samaan kehykseen';
$string['linktargettop'] = 'Samaan ikkunaan';
$string['linktitle'] = 'Otsikko';
$string['linkurl'] = 'URL';
$string['matchcase'] = 'Vastaava kirjainkoko';
$string['middle'] = 'Keskit';
$string['minimize'] = 'Pienenn editori';
$string['move'] = 'Siirr';
$string['nolink'] = 'Est automaattinen linkitys';
$string['normal'] = 'Normaali';
$string['notimage'] = 'Valittu tiedosto ei ollut kuva. Valitse kuvatiedosto!';
$string['notset'] = 'Ei valittua';
$string['ok'] = 'OK';
$string['options'] = 'Asetukset';
$string['orderedlist'] = 'Numerointi';
$string['outdent'] = 'Vhenn sisennyst';
$string['paste'] = 'Liit';
$string['path'] = 'Polku';
$string['percent'] = 'Prosenttia';
$string['pixels'] = 'Pikseli';
$string['popupeditor'] = 'Suurenna editori';
$string['preformatted'] = 'Esimuotoiltu';
$string['preview'] = 'Esikatsele';
$string['properties'] = 'Ominaisuudet';
$string['redo'] = 'Palauta viimeinen toiminto';
$string['regularexpressions'] = 'Kyt snnllisi ilmauksia';
$string['removelink'] = 'Poista linkki';
$string['rename'] = 'Nime uudelleen';
$string['replaceall'] = 'Korvaa kaikki';
$string['replacewith'] = 'Korvaa';
$string['right'] = 'Oikea';
$string['righttoleft'] = 'Suunta oikealta vasemmalle';
$string['rows'] = 'Rivit';
$string['searchandreplace'] = 'Etsi ja korvaa';
$string['searchnotfound'] = 'Etsittyj sanoja ei lydetty!';
$string['selectcolor'] = 'Valitse vri';
$string['selection'] = 'Valinta';
$string['showhelp'] = 'Ohje';
$string['size'] = 'Koko';
$string['spacing'] = 'Vlistys';
$string['strikethrough'] = 'Yliviivattu';
$string['subscript'] = 'Alaindeksi';
$string['superscript'] = 'Yldeksi';
$string['textindicator'] = 'Nykyinen tyyli';
$string['textmode'] = 'Olet tekstitilassa.  Kyt [<>] painiketta palataksesi takaisin WYSIWYG -tilaan.';
$string['texttop'] = 'Texttop';
$string['top'] = 'Yls';
$string['type'] = 'Tyyppi';
$string['underline'] = 'Alleviivattu';
$string['undo'] = 'Peruuta viimeisin toiminto';
$string['unorderedlist'] = 'Luettelomerkit';
$string['upload'] = 'Lataa';
$string['vertical'] = 'Pysty';
$string['width'] = 'Leveys';
$string['wordclean'] = 'Puhdista Word HTML';
$string['zip'] = 'Zip';

?>
